# Optimiser ses dépenses

Il existe plusieurs moyens d'optimiser ses dépenses en vacances ou en voyage.

Premièrement, on voudra économiser sur les déplacements. Est-ce qu'on voyage en voiture ou en transports publics ? Dans le premier cas, il faut considérer le coût de l'essence, du stationnement, et si vous allez dans une grande ville comme Montréal, prévoir un budget pour une contravention de stationnement (ils sont impitoyables).

Si vous utilisez le transport public, il faut examiner s'il y a des offres sur les billets, si nous sommes prêts à faire des transferts, et les horaires.

Ensuite, il faut penser à l'hébergement: Hôtel, AirBnB ou chez des amis ? Il faut considérer le coût, les services offerts ainsi que la proximité avec les attrations que l'on souhaite visiter.

Bref, tout ça peut rapidement devenir un casse-tête.

C'est à ce moment là que l'analyse de données peut nous rendre service.

## Exemple: Choisir le moyen de transport le moins cher

Je souhaite savoir, selon le kilométrage à parcourir, s'il est mieux de me déplacer à pied, en transport en commun ou en voiture.

Prenons la mise en situation suivante pour faire notre analyse:

- À vélo, le coût est nul
- En transport en commun, le coût est fixe à 3$
- En voiture, le coût de la voiture est 10\$ /heure et le stationnement est 8\$

Le temps est calculé comme suit:

- En voiture, on va à 50km/h
- En transport, on va à 20 km/h et on doit attendre 6 minutes
- À vélo, on va à 10 km/h

De plus, nous sommes prêts à dépenser 10$ pour sauver 1h de déplacement. C'est notre coût d'option.

### Faisons un peu de mathématiques

Le coût total par kilomètre se calcule comme suit, où $K$ est le nombre de kilomètres:

$$
P(K) = K*C_0 + (4+0.5*K)*C_1 + (8+0,4*K)*C_2
$$

Nous cherchons les bonnes valeurs des paramètres $C_0,C_1,C_2$, qui représentent chacun le choix d'un des trois modes de transport

$$
C_0,C_1,C_2 \in \lbrace 0,1 \rbrace \\
C_0+C_1+C_2=1 \\
$$

On minimise donc la fonction suivante:

$$
argmin_{(C_0,C_1,C_2)} (P(K))
$$

### À la recherche de solutions

À l'aide de la librairie `lpSolve` en R, on peut définir un problème d'optimisation de coût en quelques lignes et ensuite générer des scénarios.

En définissant le problème à optimiser sous la forme d'une équiation linéaire à minimiser et en calculant la solution pour toutes les distances de 1 à 50 kilomètres, nous apprendrons que:

- Avec moins de 8 kilomètres, il est préférable de prendre le vélo que tout autre mode de transport.
- À partir de 40 kilomètres, il est recommandé de prendre la voiture au lieu du transport en commun.

![Graphique du coût par kilomètre](Images/cout_moyen_transport.png)
